{% extends "pretixcontrol/event/base.html" %} {% load i18n %} {% load bootstrap3 %} {% block title %}{% trans "Send out emails" %}{% endblock %} {% block content %}

# {% trans "Email history" %}

{% for log in logs %}

- {{ log.datetime|date:"SHORT_DATETIME_FORMAT" }} {% if log.user %}
  {{ log.user.get_full_name }} {% endif %} {% if log.display %}
  {{ log.display }} {% endif %}
  {% trans "Sent to orders:" %} {% for status in log.parsed_data.sendto %} {{ status }}{% if forloop.revcounter > 1 %},{% endif %} {% endfor %} {% if log.pdata.subevent_obj %}
  {{ log.pdata.subevent_obj }} {% endif %}

  {% for locale, value in log.pdata.locales.items %}

  [{{ locale }}] {% trans "Subject:" %} {{ value.subject }}

      {{ value.message|linebreaksbr }}

  {% endfor %} {% trans "Send a new email based on this" %}
{% endfor %}

{% include "pretixcontrol/pagination.html" %} {% endblock %}